#! /bin/sh

src=../@SRCDIR@
export TEST_FINDS_EXE=Y
export PATH_SEPARATOR=:
target=djgpp
export AS=as.exe
export LD=ld.exe
export NM=nm.exe
export CC=gcc
export ac_cv_func_mmap_dev_zero=no
export lt_cv_sys_max_cmd_len=12000
export ac_cv_prog_LN='cp -p'
export ac_cv_prog_LN_S='cp -p'
export ac_cv_prog_AWK='awk'
CONFIG_SHELL=`/bin/sh -c 'echo $0'`
case $CONFIG_SHELL in *.exe) ;; *) CONFIG_SHELL=$CONFIG_SHELL.exe ;; esac
export CONFIG_SHELL
#
conf_options="$target --prefix=/dev/env/DJDIR --disable-nls --disable-werror"
#conf_options="$conf_options --enable-languages=c,c++,fortran,objc,obj-c++,ada"
conf_options="$conf_options --enable-languages=c,c++,fortran,objc,obj-c++"
conf_options="$conf_options --enable-libquadmath-support"
conf_options="$conf_options --disable-lto"
conf_options="$conf_options --disable-build-poststage1-with-cxx"
#
srcdir=`(cd $src && pwd) | sed -e 's,^[a-zA-Z]:/,/,' -e 's,^/dev/[a-zA-Z]/,/,'`
builddir=`pwd | sed -e 's,^[a-zA-Z]:/,/,' -e 's,^/dev/[a-zA-Z]/,/,'`
#
echo "Configuring GCC ..."
echo "Source directory : $srcdir"
echo "Build directory : $builddir"
#
$srcdir/configure $conf_options $*
